==> ccpem-1.0.0-linux-x86_64.tar.gz: ccpem-1.0.0/lib/py2/ccpem/src/ccpem_gui/tasks/choyce/test_choyce.py <==
#
#     Copyright (C) 2015 CCP-EM
#
#     This code is distributed under the terms and conditions of the
#     CCP-EM Program Suite Licence Agreement as a CCP-EM Application.
#     A copy of the CCP-EM licence can be obtained by writing to the
#     CCP-EM Secretary, RAL Laboratory, Harwell, OX11 0FA, UK.
#

import unittest
import os
import sys
import shutil
import time
import tempfile
from PyQt4 import QtGui, QtCore
from PyQt4.QtTest import QTest
from ccpem_core.tasks.choyce import choyce_task
from ccpem_gui.tasks.choyce import choyce_window
from ccpem_core.test_data.tasks import choyce as choyce_test
from ccpem_core import ccpem_utils
from ccpem_core import process_manager
try:
    import modeller
    modeller_available = True
except ImportError:
    modeller_available = False

app = QtGui.QApplication(sys.argv)

class Test(unittest.TestCase):
    '''
    Unit test for Choyce (invokes GUI).
    '''
    def setUp(self):
        '''
        Setup test data and output directories.
        '''
        self.test_data = os.path.dirname(choyce_test.__file__)
        self.test_output = tempfile.mkdtemp()

    def tearDown(self):
        '''
        Remove temporary data.
        '''
        if os.path.exists(path=self.test_output):
            shutil.rmtree(self.test_output)

    @unittest.skipIf(not modeller_available,
                     'Modeller not found: skipping FlexEM unittest')
    def test_choyce_window_integration(self):
        '''
        Test Choyce via GUI.
        '''
        ccpem_utils.print_header(message='Unit test - Choyce')
        os.chdir(os.path.dirname(os.path.realpath(__file__)))
        print 'Modeller version: ', modeller.__version__
        args_path = os.path.join(self.test_data, 'unittest_args.json')
        run_task = choyce_task.Choyce(job_location=self.test_output,
                                      args_json=args_path)
        # Run w/out gui
#         run_task.run_task()
        # Setup GUI
        self.window = choyce_window.ChoyceWindow(task=run_task)
        # Mouse click run
        QTest.mouseClick(
            self.window.tool_bar.widgetForAction(self.window.tb_run_button),
            QtCore.Qt.LeftButton)
        # Wait for run to complete
        self.job_completed = False
        timeout = 0
        stdout = run_task.pipeline.pipeline[0][0].stdout
        while not self.job_completed and timeout < 500:
            print '{0} running for {1} secs (timeout = 500)'.format(
                run_task.task_info.name,
                timeout)
            time.sleep(5.0)
            timeout += 5
            status =\
                process_manager.get_process_status(run_task.pipeline.json)
            if status == 'finished':
                if os.path.isfile(stdout):
                    tail = ccpem_utils.tail(stdout, maxlen=10)
                    if tail.find('CCP-EM process finished') != -1:
                        self.job_completed = True
        # Check timeout
        assert timeout < 500
        # Check job completed
        assert self.job_completed
        # Check output PDB created
        assert os.path.exists(os.path.join(self.test_output,
                                           'choyce_model.pdb'))

if __name__ == '__main__':
    unittest.main()

==> ccpem-1.5.0-linux-x86_64.tar.gz: ccpem-1.5.0/lib/py2/ccpem/src/ccpem_gui/tasks/choyce/test_choyce.py <==
#
#     Copyright (C) 2015 CCP-EM
#
#     This code is distributed under the terms and conditions of the
#     CCP-EM Program Suite Licence Agreement as a CCP-EM Application.
#     A copy of the CCP-EM licence can be obtained by writing to the
#     CCP-EM Secretary, RAL Laboratory, Harwell, OX11 0FA, UK.
#

import unittest
import os
import sys
import shutil
import time
import tempfile
from PyQt4 import QtGui, QtCore
from PyQt4.QtTest import QTest
from ccpem_core.tasks.choyce import choyce_task
from ccpem_gui.tasks.choyce import choyce_window
from ccpem_core.test_data.tasks import choyce as choyce_test
from ccpem_core import ccpem_utils
from ccpem_core import process_manager
try:
    import modeller
    modeller_available = True
except ImportError:
    modeller_available = False

app = QtGui.QApplication(sys.argv)

class Test(unittest.TestCase):
    '''
    Unit test for Choyce (invokes GUI).
    '''
    def setUp(self):
        '''
        Setup test data and output directories.
        '''
        self.test_data = os.path.dirname(choyce_test.__file__)
        self.test_output = tempfile.mkdtemp()

    def tearDown(self):
        '''
        Remove temporary data.
        '''
        if os.path.exists(path=self.test_output):
            shutil.rmtree(self.test_output)

    @unittest.skipIf(not modeller_available,
                     'Modeller not found: skipping FlexEM unittest')
    def test_choyce_window_integration(self):
        '''
        Test Choyce via GUI.
        '''
        ccpem_utils.print_header(message='Unit test - Choyce')
        os.chdir(os.path.dirname(os.path.realpath(__file__)))
        print 'Modeller version: ', modeller.__version__
        args_path = os.path.join(self.test_data, 'unittest_args.json')
        run_task = choyce_task.Choyce(job_location=self.test_output,
                                      args_json=args_path)
        # Run w/out gui
#         run_task.run_task()
        # Setup GUI
        self.window = choyce_window.ChoyceWindow(task=run_task)
        # Mouse click run
        QTest.mouseClick(
            self.window.tool_bar.widgetForAction(self.window.tb_run_button),
            QtCore.Qt.LeftButton)
        # Wait for run to complete
        self.job_completed = False
        timeout = 0
        stdout = run_task.pipeline.pipeline[0][0].stdout
        while not self.job_completed and timeout < 500:
            print '{0} running for {1} secs (timeout = 500)'.format(
                run_task.task_info.name,
                timeout)
            time.sleep(5.0)
            timeout += 5
            status =\
                process_manager.get_process_status(run_task.pipeline.json)
            if status == 'finished':
                if os.path.isfile(stdout):
                    tail = ccpem_utils.tail(stdout, maxlen=10)
                    if tail.find('CCP-EM process finished') != -1:
                        self.job_completed = True
        # Check timeout
        assert timeout < 500
        # Check job completed
        assert self.job_completed
        # Check output PDB created
        assert os.path.exists(os.path.join(self.window.task.job_location,
                                           'choyce_model.pdb'))

if __name__ == '__main__':
    unittest.main()
